%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                          %
%Dette skriptet beregner LPC koeffisienter og refleksjonskoeffisienter for %
%et gitt antall lydfiler. Det gir ut glattede FFT kurver og toppdeteksjon. %
%                                                                          % 
% Anders Torsteinb, NTNU 2007.                                            % 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all;
clc;

antallfiler=32;             %Antall filer som skal analyseres
nfft=512;                   %Sett opplsning p freqz filteret

%Kjrer analyse p alle filene
for i=1:antallfiler;
   i
    S=['Pasient 5\Respiratory Hy\P5klipp' num2str(i) '.wav'];        %Skriv inn path til de lydfilene som skal analyseres
    [y,Fs,nbits] = wavread(S);

    y = y(:,1)+ y(:,2);				% Slr sammen hyre og venstre kanal
    y = y./2;                       % Deler signalet p 2
   
    y=resample(y, 14000, Fs);       % Sampler ned til 14kHz
    Fs=14000;                       % Setter ny samplingsfrekvens    
    
    ncoeff=80;                      % Definerer orden av LPC analysen
    [A(:,i), Error, Krefl(:, i)]=arburg(y, ncoeff);     % Kjrer AR prosess av burg metoden, returnerer AR koeffisientene A og refleksjonskoeffisientene Krefl 
    [h(:,i),f]=freqz(1,A(:,i), nfft, Fs);               % Beregner frekvensrespons basert p filterkoeffisientene, returnerer frekvensamplituder h.
    
end

%Finner middelverdien for frekvensresponsene h(:,i)
for k=1:nfft       
    mean_h(k)=mean(abs(h(k,:)));                             
end

%Finner toppene i frekvensresponsen vha funskjonen findpeaks
[K,PeakAmpl]=findpeaks(mean_h,'q',10) ;

%Justerer frekvensen K slik at den blir korrekt
PeakFrekv=K*13.6;

% Genererer ett plott med frekvensresponskurve og topper gitt som prikker.
hold on;

plot(f,mean_h)
plot(PeakFrekv, PeakAmpl, 'o', 'MarkerFaceColor', 'r')

xlim([10 7000])
ylim([0 50])

xlabel('Frekvens [Hz]');
ylabel('Amplitude [dB]');

hold off;


 
 